==> Orders-1.13.tar.gz: Orders/function.defaulttemplates_tab.php <==
<?php
#-------------------------------------------------------------------------
# Module: Orders - A simple order processing module.
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in every page of
# its admin section that the site was built with CMS Made simple, and
# provide a link to the CMS Made Simple website.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') )
  {
    echo $this->ShowErrors($this->Lang('error_permissiondenied'));
    return;
  }

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
				    'systemdflt_billingform_template',
				   'admin_templates','defaulttemplates',
				    $this->Lang('dflt_billingform_template'),
				    'orig_billingform_template.tpl',
				    $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_paymentform_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_paymentform_template'),
			       'orig_paymentform_template.tpl',
			       $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_confirmorder_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_confirmorder_template'),
			       'orig_confirmorder_template.tpl',
			       $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_invoice_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_invoice_template'),
			       'orig_invoice_template.tpl',
			       $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_gateway_complete_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_gateway_complete_template'),
			       'orig_gateway_complete_template.tpl',
			       $this->Lang('info_default_templates'));



// EOF
?>

==> Orders-1.15.2.tar.gz: Orders/function.defaulttemplates_tab.php <==
<?php
#-------------------------------------------------------------------------
# Module: Orders - A simple order processing module.
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in every page of
# its admin section that the site was built with CMS Made simple, and
# provide a link to the CMS Made Simple website.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') )
  {
    echo $this->ShowErrors($this->Lang('error_permissiondenied'));
    return;
  }

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
				    'systemdflt_billingform_template',
				   'admin_templates','defaulttemplates',
				    $this->Lang('dflt_billingform_template'),
				    'orig_billingform_template.tpl',
				    $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_shippingform_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_shippingform_template'),
			       'orig_shippingform_template.tpl',
			       $this->Lang('info_default_templates'));


echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_confirmorder_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_confirmorder_template'),
			       'orig_confirmorder_template.tpl',
			       $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_invoice_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_invoice_template'),
			       'orig_invoice_template.tpl',
			       $this->Lang('info_default_templates'));

echo $this->GetDefaultTemplateForm($this,$id,$returnid,
			       'systemdflt_gateway_complete_template',
			       'admin_templates','defaulttemplates',
			       $this->Lang('dflt_gateway_complete_template'),
			       'orig_gateway_complete_template.tpl',
			       $this->Lang('info_default_templates'));



// EOF
?>
